@@ -341,7 +341,7 @@ def create_adjusted_model_for_percentages(model_src, model_use):
         f.write(content)
 
 
-def evaluate_model(recording, model_folder, showit=False):
+def evaluate_model(recording, model_folder, verbose=False):
     """Evaluate model for a single recording."""
 
     folders = []
@@ -362,10 +362,10 @@ def evaluate_model(recording, model_folder, showit=False):
             t = target_folder
             _, _, preprocessing_queue = preprocess_dataset.get_parameters(t)
             handwriting = HandwrittenData(recording)
-            if showit:
+            if verbose:
                 handwriting.show()
             handwriting.preprocessing(preprocessing_queue)
-            if showit:
+            if verbose:
                 logging.debug("After preprocessing: %s",
                               handwriting.get_sorted_pointlist())
                 handwriting.show()
@@ -423,11 +423,11 @@ def evaluate_model(recording, model_folder, showit=False):
             logging.info("'%s' not found", target_folder)
 
 
-def classify_single_recording(raw_data_json, model_folder):
+def classify_single_recording(raw_data_json, model_folder, verbose=False):
     """Get the classification as a list of tuples. The first value is the
        LaTeX code, the second value is the probability.
     """
-    evaluation_file = evaluate_model(raw_data_json, model_folder)
+    evaluation_file = evaluate_model(raw_data_json, model_folder, verbose)
     PROJECT_ROOT = get_project_root()
     with open(os.path.join(model_folder, "info.yml")) as ymlfile:
             model_description = yaml.load(ymlfile)
